package com.allpayx.atsmpservice.aop;

import com.allpayx.atsmpservice.exception.CheckException;
import com.allpayx.atsmpservice.exception.FormalException;


import com.allpayx.atsmpservice.model.vo.ResultVO;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.validation.BindException;
import org.springframework.validation.BindingResult;
import org.springframework.validation.FieldError;
import org.springframework.validation.ObjectError;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;


/**
 * Created by zhang on 2018/12/21.
 */
@ControllerAdvice(annotations = {RestController.class, Controller.class} )
@ResponseBody
@Slf4j
public class RestExceptionHandler {

    private static final Logger logger = LoggerFactory.getLogger(RestExceptionHandler.class);

    @ExceptionHandler(Exception.class)
    @ResponseBody
    public Object exceptionHandler(Exception e) {
        if (e instanceof CheckException) {
            // 异常信息
            log.debug("e:" + e);
            // 返回对象
            ResultVO<Object> resultVO = new ResultVO<>();
            resultVO.setStatus(ResultVO.FAIL);
            resultVO.setMessage(e.getLocalizedMessage());
            log.info("errorInfo:" + e.getLocalizedMessage());
            resultVO.setMessage(e.getMessage());
            return resultVO;
        }
        if (e instanceof FormalException) {
            ResultVO<Object> ResultVO = new ResultVO<>();
            ResultVO.setMessage(e.getMessage());
            return ResultVO;
        }
        e.printStackTrace();
        log.debug("其他未处理异常，统一处理");
        ResultVO<Object> resultVO = new ResultVO<>();
        resultVO.setStatus(ResultVO.FAIL);
        resultVO.setMessage(e.getLocalizedMessage());
        log.debug("errorInfo1:" + e.getLocalizedMessage());
        return resultVO;
    }

    /**
     * 异常信息
     *
     * @param result
     * @return
     */
    private String extractErrorMsg(BindingResult result) {
        List<FieldError> errors = result.getFieldErrors();

        return errors.stream().map(e -> e.getField() + ":" + e.getDefaultMessage())
                .reduce((s1, s2) -> s1 + " ; " + s2).orElseGet(() -> "参数非法");
    }

    @ExceptionHandler(ConstraintViolationException.class)
    public Map handleConstraintViolationException(ConstraintViolationException cve) {
        Set<ConstraintViolation<?>> cves = cve.getConstraintViolations();
        String defaultMessage=null;
        for (ConstraintViolation<?> constraintViolation : cves) {
            defaultMessage=constraintViolation.getMessage();
            logger.info(defaultMessage);
        }
        Map map = new HashMap();
        map.put("errorCode", 500);
        map.put("errorInfo",defaultMessage);
        return map;

    }

    @ExceptionHandler(BindException.class)
    public Map handleConstraintViolationExceptionBingding(BindException cve) {
        List<ObjectError> allErrors = cve.getAllErrors();
        String defaultMessage=null;
        for (ObjectError constraintViolation : allErrors) {
            defaultMessage = constraintViolation.getDefaultMessage();
            logger.info(defaultMessage);
        }
        Map map = new HashMap();
        map.put("errorCode", 500);
        map.put("errorInfo",defaultMessage);
        return map;
    }
}
