package com.allpayx.atsmpservice.controller;

import com.allpayx.atsmpservice.model.vo.ResultVO;
import com.allpayx.atsmpservice.param.RequestParam.RecoredConfirmInfoRequest;
import com.allpayx.atsmpservice.param.ResponseParam.RecoredConfirmInfoResponse;
import com.allpayx.atsmpservice.service.UserService;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

@Slf4j
@RestController
@RequestMapping("ats")
@CrossOrigin
@Validated
public class AtsController {
    @Autowired
    private UserService userService;

    /**
     *  入账信息查询
     * @param recoredConfirmInfo
     * @return
     */
    @RequestMapping("select_recored_confirm_info")
    public ResultVO selectRecordConfirmInfo(@Validated RecoredConfirmInfoRequest recoredConfirmInfo) {
        PageInfo<RecoredConfirmInfoResponse> recoredConfirmInfoResponse = userService.selectRecordConfirmInfo(recoredConfirmInfo);
        ResultVO resultVO = new ResultVO();
        resultVO.setMessage("入账信息查询成功");
        resultVO.setData(recoredConfirmInfoResponse);
        return resultVO;
    }

    /**
     * 导出入账信息报表
     * @param recoredConfirmInfo
     * @return
     */
    @RequestMapping("get_recored_export_report")
    public ResultVO getRecoredExportReport(RecoredConfirmInfoRequest recoredConfirmInfo) {
        List<RecoredConfirmInfoResponse> recoredConfirmInfoResponse=userService.getRecoredExportReport(recoredConfirmInfo);
        ResultVO resultVO = new ResultVO();
        resultVO.setMessage("导出入账信息报表成功");
        resultVO.setData(recoredConfirmInfoResponse);
        return resultVO;
    }

    /**
     * 导入入账信息Excel表格文件
     * @param file
     * @return
     */
    @RequestMapping(value = "insert_recored_import_report" ,method = RequestMethod.POST)
    public ResultVO insertRecoredImportReport(@RequestParam(value = "file") MultipartFile file) {
        userService.insertRecoredImportReport(file);
        ResultVO resultVO = new ResultVO();
        resultVO.setMessage("导入入账信息报表成功");
        return resultVO;
    }

    /**
     * 入账确认
     * @param recoredConfirmInfo
     * @return
     */
    @RequestMapping(value = "update_recored_confirm_status" )
    public ResultVO updateRecoredConfirmStatus(RecoredConfirmInfoRequest recoredConfirmInfo) {
        userService.updateRecoredConfirmStatus(recoredConfirmInfo);
        ResultVO resultVO = new ResultVO();
        resultVO.setMessage("入账确认操作成功");
        return resultVO;
    }
}
